==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/d58/road__map_8h.js <==
var road__map_8h =
[
    [ "EnumPropsT< DisallowedRoadDirections >", "d6/d35/structEnumPropsT_3_01DisallowedRoadDirections_01_4.html", null ],
    [ "IsOnDesert", "d8/d58/road__map_8h.html#a12e4cbaa9c663671036b239da0ae37b5", null ],
    [ "ToggleDesert", "d8/d58/road__map_8h.html#a61891523c6358a1106f78d4f7e0578b3", null ],
    [ "DisallowedRoadDirections", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1", [
      [ "DRD_NONE", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1ad3f9960cd5f24c858df484e8c2a8b8eb", null ],
      [ "DRD_SOUTHBOUND", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1af4d3db022f8bb07fe4416c5dfdd70926", null ],
      [ "DRD_NORTHBOUND", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a14d3ac0125779aceb47d305d5fcee74d", null ],
      [ "DRD_BOTH", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a86187019aa1b5ca72a278115e381dc39", null ],
      [ "DRD_END", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a252370da2d6b8fa41f5b016417fe9552", null ]
    ] ],
    [ "Roadside", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864b", [
      [ "ROADSIDE_BARREN", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864badd2f523bc8c34e9d0f55043eeb57045e", null ],
      [ "ROADSIDE_GRASS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864bae4695cffeb5828ab2020a29d0a84a18b", null ],
      [ "ROADSIDE_PAVED", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864ba946600ae33f2ff9a089b5429b42092b1", null ],
      [ "ROADSIDE_STREET_LIGHTS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864bacb2e2d1fb172d81fa2b639edfa9d2dd7", null ],
      [ "ROADSIDE_TREES", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864baeaf31b45b4b3e46087ac9d4c6cdbc8a3", null ],
      [ "ROADSIDE_GRASS_ROAD_WORKS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864ba5e8274b733ae89e7acdcefa17a289c96", null ],
      [ "ROADSIDE_PAVED_ROAD_WORKS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864baac5a9b2b0f49e8e7ad2a8fee262e1ec7", null ]
    ] ],
    [ "RoadTileType", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471f", [
      [ "ROAD_TILE_NORMAL", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471fa56f9619324d2d2eced0b9f6e2bc530cd", null ],
      [ "ROAD_TILE_CROSSING", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471faea40d4af90e209ae55959d99124b539d", null ],
      [ "ROAD_TILE_DEPOT", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471fab8633cc463907eba283143f40ec63aa4", null ]
    ] ],
    [ "BarCrossing", "d8/d58/road__map_8h.html#aa1e045e9c67efbc1db90e6c86734dc7d", null ],
    [ "GetAllRoadBits", "d8/d58/road__map_8h.html#a77fd61fc82f475c61ca639b60c84a4d0", null ],
    [ "GetAnyRoadBits", "d8/d58/road__map_8h.html#a79db50cadcc5475a657bee6b4c00ebc6", null ],
    [ "GetCrossingRailAxis", "d8/d58/road__map_8h.html#ab9a805d24dfe2d87b86def4fd576d8a4", null ],
    [ "GetCrossingRailBits", "d8/d58/road__map_8h.html#ae71cf8bc5fb9b269bfd486851ec204b5", null ],
    [ "GetCrossingRailTrack", "d8/d58/road__map_8h.html#ac7b2158b070552303549df7fcd876698", null ],
    [ "GetCrossingReservationTrackBits", "d8/d58/road__map_8h.html#a940c91b53e8da6392871c8fb0ba0b779", null ],
    [ "GetCrossingRoadAxis", "d8/d58/road__map_8h.html#a1ab433587c6ead4a2bf9bed390a6fc01", null ],
    [ "GetCrossingRoadBits", "d8/d58/road__map_8h.html#a103c09a40e48c3eb1b461d528f47b21a", null ],
    [ "GetDisallowedRoadDirections", "d8/d58/road__map_8h.html#a040038a92354850d5845fd0feded8fe0", null ],
    [ "GetOtherRoadBits", "d8/d58/road__map_8h.html#a7e1ab49acbf26fdece132cd2a3bd08d5", null ],
    [ "GetRoadBits", "d8/d58/road__map_8h.html#a92ec2bc07447e27bf6d1fd07d9b357aa", null ],
    [ "GetRoadDepotDirection", "d8/d58/road__map_8h.html#aaa50435a9cbcfbcd889a461ab7726b82", null ],
    [ "GetRoadOwner", "d8/d58/road__map_8h.html#a094478364256a2c84f8323912639059c", null ],
    [ "GetRoadside", "d8/d58/road__map_8h.html#a9f57fdd9bfca3082b67153845a51e7d6", null ],
    [ "GetRoadTileType", "d8/d58/road__map_8h.html#ac1621ecc56b607fabfaab3f92e07f90a", null ],
    [ "GetRoadTypes", "d8/d58/road__map_8h.html#aeda466761b26cc4a3484af4cde46b63a", null ],
    [ "HasCrossingReservation", "d8/d58/road__map_8h.html#ac771f3205eca81b68cda2bc70b16ff92", null ],
    [ "HasRoadWorks", "d8/d58/road__map_8h.html#a629571256872a4e5b10a448669028daa", null ],
    [ "HasTileRoadType", "d8/d58/road__map_8h.html#ad549a8d311f5658928a791d6d0327809", null ],
    [ "HasTownOwnedRoad", "d8/d58/road__map_8h.html#a0425920d1b32cdc51bbb3e373e2b71e7", null ],
    [ "IncreaseRoadWorksCounter", "d8/d58/road__map_8h.html#a15d0c9719e063407b54554a8cbba2d9f", null ],
    [ "IsCrossingBarred", "d8/d58/road__map_8h.html#aa8652785fed0dc5c17befe3381c1a01c", null ],
    [ "IsLevelCrossing", "d8/d58/road__map_8h.html#adabb5bf876290406700f1408a6e8d974", null ],
    [ "IsLevelCrossingTile", "d8/d58/road__map_8h.html#a98310e5655ac1e470b0d4de429052f91", null ],
    [ "IsNormalRoad", "d8/d58/road__map_8h.html#a78db74827ff79467d44607094eedef1d", null ],
    [ "IsNormalRoadTile", "d8/d58/road__map_8h.html#a1d3819abde8112ea9d1dd3a47c21f169", null ],
    [ "IsOnSnow", "d8/d58/road__map_8h.html#a465263655b14c03478e130c0ece73a02", null ],
    [ "IsRoadDepot", "d8/d58/road__map_8h.html#a65d022e38f6c55e07b953b0a9cdcdf03", null ],
    [ "IsRoadDepotTile", "d8/d58/road__map_8h.html#ab3b85dd31bcebc0607254fed81109504", null ],
    [ "IsRoadOwner", "d8/d58/road__map_8h.html#a0d210a495e73bd9f9bd152bd3d5094fa", null ],
    [ "MakeRoadCrossing", "d8/d58/road__map_8h.html#a631681d31eda53dc808dfeaad18d4f01", null ],
    [ "MakeRoadDepot", "d8/d58/road__map_8h.html#a750cb2858182d78aa425378cb799368b", null ],
    [ "MakeRoadNormal", "d8/d58/road__map_8h.html#aae5bd41d4ab416ab3d12c0b74513395c", null ],
    [ "SetCrossingBarred", "d8/d58/road__map_8h.html#a25ddcc534aaff81cf922d122923b4b7d", null ],
    [ "SetCrossingReservation", "d8/d58/road__map_8h.html#ad459de7de78838e6420306d3ad7304b0", null ],
    [ "SetDisallowedRoadDirections", "d8/d58/road__map_8h.html#a0d7787536d75bcb4d350ad75b6bcbc0b", null ],
    [ "SetRoadBits", "d8/d58/road__map_8h.html#a3811c1b5d8a29878312a1ab392a2ea4f", null ],
    [ "SetRoadOwner", "d8/d58/road__map_8h.html#aef8ab32e60fac18d19b7bd023ee5a060", null ],
    [ "SetRoadside", "d8/d58/road__map_8h.html#a33b5fae069f655bd7c5b88ef46953ace", null ],
    [ "SetRoadTypes", "d8/d58/road__map_8h.html#a6512430926bc071581060d3a840c2fcf", null ],
    [ "StartRoadWorks", "d8/d58/road__map_8h.html#a712c61500e4f0120b2ae504cb5d51084", null ],
    [ "TerminateRoadWorks", "d8/d58/road__map_8h.html#af6c9fd97b911cb799af1a25fbc635221", null ],
    [ "ToggleSnow", "d8/d58/road__map_8h.html#a7e4562aca5566eb41ffe6986a57d8bda", null ],
    [ "UnbarCrossing", "d8/d58/road__map_8h.html#a6dbf979ca786fd9318a95528ce21154e", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/d58/road__map_8h.js <==
var road__map_8h =
[
    [ "EnumPropsT< DisallowedRoadDirections >", "d6/d35/structEnumPropsT_3_01DisallowedRoadDirections_01_4.html", null ],
    [ "IsOnDesert", "d8/d58/road__map_8h.html#a12e4cbaa9c663671036b239da0ae37b5", null ],
    [ "ToggleDesert", "d8/d58/road__map_8h.html#a61891523c6358a1106f78d4f7e0578b3", null ],
    [ "DisallowedRoadDirections", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1", [
      [ "DRD_NONE", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1ad3f9960cd5f24c858df484e8c2a8b8eb", null ],
      [ "DRD_SOUTHBOUND", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1af4d3db022f8bb07fe4416c5dfdd70926", null ],
      [ "DRD_NORTHBOUND", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a14d3ac0125779aceb47d305d5fcee74d", null ],
      [ "DRD_BOTH", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a86187019aa1b5ca72a278115e381dc39", null ],
      [ "DRD_END", "d8/d58/road__map_8h.html#ac20f9e6dea4b83e3c47a396f452b90a1a252370da2d6b8fa41f5b016417fe9552", null ]
    ] ],
    [ "Roadside", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864b", [
      [ "ROADSIDE_BARREN", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864badd2f523bc8c34e9d0f55043eeb57045e", null ],
      [ "ROADSIDE_GRASS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864bae4695cffeb5828ab2020a29d0a84a18b", null ],
      [ "ROADSIDE_PAVED", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864ba946600ae33f2ff9a089b5429b42092b1", null ],
      [ "ROADSIDE_STREET_LIGHTS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864bacb2e2d1fb172d81fa2b639edfa9d2dd7", null ],
      [ "ROADSIDE_TREES", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864baeaf31b45b4b3e46087ac9d4c6cdbc8a3", null ],
      [ "ROADSIDE_GRASS_ROAD_WORKS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864ba5e8274b733ae89e7acdcefa17a289c96", null ],
      [ "ROADSIDE_PAVED_ROAD_WORKS", "d8/d58/road__map_8h.html#a4a307fd015db697c08f3aee02877864baac5a9b2b0f49e8e7ad2a8fee262e1ec7", null ]
    ] ],
    [ "RoadTileType", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471f", [
      [ "ROAD_TILE_NORMAL", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471fa56f9619324d2d2eced0b9f6e2bc530cd", null ],
      [ "ROAD_TILE_CROSSING", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471faea40d4af90e209ae55959d99124b539d", null ],
      [ "ROAD_TILE_DEPOT", "d8/d58/road__map_8h.html#a2e9ef9177ef89669b1f8bf065a61471fab8633cc463907eba283143f40ec63aa4", null ]
    ] ],
    [ "BarCrossing", "d8/d58/road__map_8h.html#aa1e045e9c67efbc1db90e6c86734dc7d", null ],
    [ "GetAllRoadBits", "d8/d58/road__map_8h.html#a77fd61fc82f475c61ca639b60c84a4d0", null ],
    [ "GetAnyRoadBits", "d8/d58/road__map_8h.html#a9bda856754f80b77efe1b5b5e2cf6b62", null ],
    [ "GetCrossingRailAxis", "d8/d58/road__map_8h.html#ab9a805d24dfe2d87b86def4fd576d8a4", null ],
    [ "GetCrossingRailBits", "d8/d58/road__map_8h.html#ae71cf8bc5fb9b269bfd486851ec204b5", null ],
    [ "GetCrossingRailTrack", "d8/d58/road__map_8h.html#ac7b2158b070552303549df7fcd876698", null ],
    [ "GetCrossingReservationTrackBits", "d8/d58/road__map_8h.html#a940c91b53e8da6392871c8fb0ba0b779", null ],
    [ "GetCrossingRoadAxis", "d8/d58/road__map_8h.html#a1ab433587c6ead4a2bf9bed390a6fc01", null ],
    [ "GetCrossingRoadBits", "d8/d58/road__map_8h.html#a103c09a40e48c3eb1b461d528f47b21a", null ],
    [ "GetDisallowedRoadDirections", "d8/d58/road__map_8h.html#a040038a92354850d5845fd0feded8fe0", null ],
    [ "GetPresentRoadTypes", "d8/d58/road__map_8h.html#a7906be19cd49d9ecde3a9ebf074c1791", null ],
    [ "GetRoadBits", "d8/d58/road__map_8h.html#a07c7c5cb1f9264d7b01ada4a29bebc5c", null ],
    [ "GetRoadDepotDirection", "d8/d58/road__map_8h.html#aaa50435a9cbcfbcd889a461ab7726b82", null ],
    [ "GetRoadOwner", "d8/d58/road__map_8h.html#a048823e0dfb17afa7d0030bcd000f6cd", null ],
    [ "GetRoadside", "d8/d58/road__map_8h.html#a9f57fdd9bfca3082b67153845a51e7d6", null ],
    [ "GetRoadTileType", "d8/d58/road__map_8h.html#ac1621ecc56b607fabfaab3f92e07f90a", null ],
    [ "GetRoadType", "d8/d58/road__map_8h.html#adadf1b8b07af3f013e49cc42463f7ce5", null ],
    [ "GetRoadTypeRoad", "d8/d58/road__map_8h.html#ac1c2283b8414e90b0f4d32fa9624ea3c", null ],
    [ "GetRoadTypeTram", "d8/d58/road__map_8h.html#ab23d9dfdeb82d8b69bd95fa5b2b2a903", null ],
    [ "HasCrossingReservation", "d8/d58/road__map_8h.html#ac771f3205eca81b68cda2bc70b16ff92", null ],
    [ "HasRoadTypeRoad", "d8/d58/road__map_8h.html#a2ba8da7f51fd7ebdc6ed9c6c759871fe", null ],
    [ "HasRoadTypeTram", "d8/d58/road__map_8h.html#a96c2ae3074426bc2a4d10a9dd9721830", null ],
    [ "HasRoadWorks", "d8/d58/road__map_8h.html#a629571256872a4e5b10a448669028daa", null ],
    [ "HasTileAnyRoadType", "d8/d58/road__map_8h.html#ae91ead5bb22784c78c4b7ecc14c5b8ed", null ],
    [ "HasTileRoadType", "d8/d58/road__map_8h.html#a896331901f999e41fa69a4ac4be3e942", null ],
    [ "HasTownOwnedRoad", "d8/d58/road__map_8h.html#a0425920d1b32cdc51bbb3e373e2b71e7", null ],
    [ "IncreaseRoadWorksCounter", "d8/d58/road__map_8h.html#a15d0c9719e063407b54554a8cbba2d9f", null ],
    [ "IsCrossingBarred", "d8/d58/road__map_8h.html#aa8652785fed0dc5c17befe3381c1a01c", null ],
    [ "IsLevelCrossing", "d8/d58/road__map_8h.html#adabb5bf876290406700f1408a6e8d974", null ],
    [ "IsLevelCrossingTile", "d8/d58/road__map_8h.html#a98310e5655ac1e470b0d4de429052f91", null ],
    [ "IsNormalRoad", "d8/d58/road__map_8h.html#a78db74827ff79467d44607094eedef1d", null ],
    [ "IsNormalRoadTile", "d8/d58/road__map_8h.html#a1d3819abde8112ea9d1dd3a47c21f169", null ],
    [ "IsOnSnow", "d8/d58/road__map_8h.html#a465263655b14c03478e130c0ece73a02", null ],
    [ "IsRoadDepot", "d8/d58/road__map_8h.html#a65d022e38f6c55e07b953b0a9cdcdf03", null ],
    [ "IsRoadDepotTile", "d8/d58/road__map_8h.html#ab3b85dd31bcebc0607254fed81109504", null ],
    [ "IsRoadOwner", "d8/d58/road__map_8h.html#adf9c0eea8342e75ec6203f04fa834ede", null ],
    [ "MakeRoadCrossing", "d8/d58/road__map_8h.html#acf92883fc23a60ca4c0893ee77d62e75", null ],
    [ "MakeRoadDepot", "d8/d58/road__map_8h.html#a750cb2858182d78aa425378cb799368b", null ],
    [ "MakeRoadNormal", "d8/d58/road__map_8h.html#a86a6c006f11c286e70618b3e59b4906a", null ],
    [ "MayHaveRoad", "d8/d58/road__map_8h.html#a8d8fda5ae5e6ab66ddbfe108b42575fe", null ],
    [ "SetCrossingBarred", "d8/d58/road__map_8h.html#a25ddcc534aaff81cf922d122923b4b7d", null ],
    [ "SetCrossingReservation", "d8/d58/road__map_8h.html#ad459de7de78838e6420306d3ad7304b0", null ],
    [ "SetDisallowedRoadDirections", "d8/d58/road__map_8h.html#a0d7787536d75bcb4d350ad75b6bcbc0b", null ],
    [ "SetRoadBits", "d8/d58/road__map_8h.html#a068cb8f8c4943ad515e424b9b0e23aa5", null ],
    [ "SetRoadOwner", "d8/d58/road__map_8h.html#a1ee7a8dab54e9c891c237f9394b370ff", null ],
    [ "SetRoadside", "d8/d58/road__map_8h.html#a33b5fae069f655bd7c5b88ef46953ace", null ],
    [ "SetRoadType", "d8/d58/road__map_8h.html#ae90d18254d28681c975ce332efa3a592", null ],
    [ "SetRoadTypeRoad", "d8/d58/road__map_8h.html#a936b619e2dfa5bd1167d87d69b4492f0", null ],
    [ "SetRoadTypes", "d8/d58/road__map_8h.html#a03070900b284fff535e53694fcdd8cec", null ],
    [ "SetRoadTypeTram", "d8/d58/road__map_8h.html#a6e22168d259a1834efa10ed440a479b9", null ],
    [ "StartRoadWorks", "d8/d58/road__map_8h.html#a712c61500e4f0120b2ae504cb5d51084", null ],
    [ "TerminateRoadWorks", "d8/d58/road__map_8h.html#af6c9fd97b911cb799af1a25fbc635221", null ],
    [ "ToggleSnow", "d8/d58/road__map_8h.html#a7e4562aca5566eb41ffe6986a57d8bda", null ],
    [ "UnbarCrossing", "d8/d58/road__map_8h.html#a6dbf979ca786fd9318a95528ce21154e", null ]
];
